@@ -5,8 +5,6 @@ import sys
 import os
 
 workDir = os.path.dirname(os.path.abspath(__file__))
-workDir = workDir.split("/")[:-1]
-workDir = "/".join(workDir)
 
 class createGraph:
 	def __init__(self, data):
@@ -29,9 +27,8 @@ class createGraph:
 		plt.show()
 		
 def main():
-	dataPath = os.path.join(workDir, 'utils')
 	if len(sys.argv) > 1:
-		fileName = pd.read_csv(os.path.join(dataPath,sys.argv[1]))
+		fileName = pd.read_csv(os.path.join(workDir,sys.argv[1]))
 	else:
 		fileName = pd.read_csv(os.path.join(dataPath,'fgvt-steering-data.csv'))
 	graphObject = createGraph(fileName)
